# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['edu_rdm_integration',
 'edu_rdm_integration.adapters',
 'edu_rdm_integration.collect_data',
 'edu_rdm_integration.collect_data.base',
 'edu_rdm_integration.collect_data.calculated',
 'edu_rdm_integration.collect_data.calculated.base',
 'edu_rdm_integration.collect_data.non_calculated',
 'edu_rdm_integration.collect_data.non_calculated.base',
 'edu_rdm_integration.export_data',
 'edu_rdm_integration.export_data.base',
 'edu_rdm_integration.management',
 'edu_rdm_integration.management.commands',
 'edu_rdm_integration.migrations']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'edu-rdm-integration',
    'version': '0.1.1',
    'description': 'Интеграция с Региональной витриной данных',
    'long_description': '# Проект "Интеграция с Региональной витриной данных"\n\n## Описание концепции\n\n## Принцип работы\n\n## Требования к окружению\n\n## Разворачивание\n\n## Параметры конфигурационного файла\n\n\nВ разных проектах существуют различные способы добавления настроек, где-то через плагины, где-то напрямую в settings.py.\nБудет рассмотрен подход указания настроек в settings.py и указания параметров в конфигурационном файле.\n\nДля возможности конфигурирования необходимо проделать ряд действий. В settings.py нужно добавить:\n\n- Определение значений по умолчанию настроек:\n    ```\n    PROJECT_DEFAULT_CONFIG.update({\n        # Настройки РВД\n        (\'rdm_general\', \'EXPORT_ENTITY_ID_PREFIX\'): \'\', # Дефолтное значение нужно изменить на специфическое системе\n        (\'rdm_general\', \'COLLECT_CHUNK_SIZE\'): 500,\n        (\'rdm_general\', \'EXPORT_CHUNK_SIZE\'): 500,\n        (\'rdm_transfer_task\', \'MINUTE\'): \'0\',\n        (\'rdm_transfer_task\', \'HOUR\'): \'*/4\',\n        (\'rdm_transfer_task\', \'TRANSFER_TASK_DAY_OF_WEEK\'): \'*\',\n        (\'rdm_transfer_task\', \'TIMEDELTA\'): 3600,\n        (\'rdm_upload_status_task\', \'MINUTE\'): \'*/30\',\n        (\'rdm_upload_status_task\', \'HOUR\'): \'*\',\n        (\'rdm_upload_status_task\', \'DAY_OF_WEEK\'): \'*\',\n        (\'uploader_client\', \'URL\'): \'http://localhost:8090\',\n        (\'uploader_client\', \'DATAMART_NAME\'): \'\',\n        (\'uploader_client\', \'REQUEST_RETRIES\'): 10,\n        (\'uploader_client\', \'REQUEST_TIMEOUT\'): 10,\n        (\'uploader_client\', \'ENABLE_REQUEST_EMULATION\'): False,\n    })\n    ```\n- Получение значений настроек из конфигурационного файла:\n\n    ```\n    # Ссылка на каталог с файлами для загрузки\n    UPLOADS = \'uploads\'\n  \n    # =============================================================================\n    # Интеграция с Региональной витриной данных (РВД)\n    # =============================================================================\n    \n    # Префикс идентификаторов записей сущностей специфический для продукта\n    RDM_EXPORT_ENTITY_ID_PREFIX = conf.get(\'rdm_general\', \'EXPORT_ENTITY_ID_PREFIX\') \n  \n    # Количество записей моделей ЭШ обрабатываемых за одну итерацию сбора данных\n    RDM_COLLECT_CHUNK_SIZE = conf.get_int(\'rdm_general\', \'COLLECT_CHUNK_SIZE\')\n    \n    # Количество записей моделей обрабатываемых за одну итерацию экспорта данных\n    RDM_EXPORT_CHUNK_SIZE = conf.get_int(\'rdm_general\', \'EXPORT_CHUNK_SIZE\')\n    \n    # Настройка запуска периодической задачи выгрузки данных:\n    RDM_TRANSFER_TASK_MINUTE = conf.get(\'rdm_transfer_task\', \'MINUTE\')\n    RDM_TRANSFER_TASK_HOUR = conf.get(\'rdm_transfer_task\', \'HOUR\')\n    RDM_TRANSFER_TASK_DAY_OF_WEEK = conf.get(\'rdm_transfer_task\', \'DAY_OF_WEEK\')\n    RDM_TRANSFER_TASK_TIMEDELTA = conf.get_int(\'rdm_transfer_task\', \'TIMEDELTA\')\n    \n    # Настройка запуска периодической задачи статуса загрузки данных в витрину:\n    RDM_UPLOAD_STATUS_TASK_MINUTE = conf.get(\'rdm_upload_status_task\', \'MINUTE\')\n    RDM_UPLOAD_STATUS_TASK_HOUR = conf.get(\'rdm_upload_status_task\', \'HOUR\')\n    RDM_UPLOAD_STATUS_TASK_DAY_OF_WEEK = conf.get(\'rdm_upload_status_task\', \'DAY_OF_WEEK\')\n    \n    # Загрузка данных в Региональную витрину данных (РВД)\n    # Адрес витрины (schema://host:port)\n    RDM_UPLOADER_CLIENT_URL = conf.get(\'uploader_client\', \'URL\')\n    \n    # Мнемоника Витрины\n    RDM_UPLOADER_CLIENT_DATAMART_NAME = conf.get(\'uploader_client\', \'DATAMART_NAME\')\n    \n    # Количество повторных попыток запроса\n    RDM_UPLOADER_CLIENT_REQUEST_RETRIES = conf.get_int(\'uploader_client\', \'REQUEST_RETRIES\')\n    \n    # Таймаут запроса, сек\n    RDM_UPLOADER_CLIENT_REQUEST_TIMEOUT = conf.get_int(\'uploader_client\', \'REQUEST_TIMEOUT\')\n    \n    # Включить эмуляцию отправки запросов\n    RDM_UPLOADER_CLIENT_ENABLE_REQUEST_EMULATION = conf.get_bool(\'uploader_client\', \'ENABLE_REQUEST_EMULATION\')\n    \n    ```\n\nВ дефолтный конфиг проекта необходимо добавить:\n\n```\n# Общие настройки интеграции с РВД\n[rmd_general]\n# Префикс идентификаторов записей сущностей специфический для продукта. Указывается в settings.py и не должен \n# изменяться. Возможность изменения через конфигурационный файл оставлена для экстренных случаев.\n# EXPORT_ENTITY_ID_PREFIX = \n# Количество записей моделей обрабатываемых за одну итерацию экспорта данных\nEXPORT_CHUNK_SIZE = 500\n# Количество записей моделей ЭШ обрабатываемых за одну итерацию сбора данных\nCOLLECT_CHUNK_SIZE = 500\n\n# Настройка запуска периодической задачи выгрузки данных\n[rdm_transfer_task]\nMINUTE=*/2\nHOUR=*\nDAY_OF_WEEK=*\n# Дельта между прошлым и текущим запуском, сек\nTIMEDELTA=120\n\n# Настройка запуска периодической задачи статуса загрузки данных в витрину\n[rdm_upload_status_task]\nMINUTE=*/2\nHOUR=*\nDAY_OF_WEEK=*\n\n[uploader_client]\n# Адрес витрины\nURL = http://localhost:8090\n# Мнемоника Витрины\nDATAMART_NAME = test\n# Количество повторных попыток запроса\nREQUEST_RETRIES = 10\n# Таймаут запроса, сек\nREQUEST_TIMEOUT = 10\n# Включить эмуляцию отправки запросов\nENABLE_REQUEST_EMULATION = True\n```\n\nНа основе дефолтного конфига произвести конфигурирование приложений.\n\nПеречень настроек в settings.py указан в таблице ниже.\n\n| Название настройки в settings                | Описание                                                                                                                           | Значение по умолчанию   |\n|----------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------|-------------------------|\n| UPLOADS                                      | Основная директория в MEDIA, в которой будет создана директория edu_rdm_integration  для сохранения файлов для дальнейшей выгрузки | 500                     |\n| RDM_COLLECT_CHUNK_SIZE                       | Количество записей моделей обрабатываемых за одну итерацию сбора данных                                                            | 500                     |\n| RDM_EXPORT_CHUNK_SIZE                        | Количество записей моделей обрабатываемых за одну итерацию экспорта                                                                | 500                     |\n| RDM_UPLOADER_CLIENT_URL                      | Адрес витрины (schema://host:port)                                                                                                 | \'http://localhost:8090\' |\n| RDM_UPLOADER_CLIENT_DATAMART_NAME            | Мнемоника Витрины                                                                                                                  | \'test\'                  |\n| RDM_UPLOADER_CLIENT_REQUEST_RETRIES          | Количество повторных попыток запроса                                                                                               | 10                      |\n| RDM_UPLOADER_CLIENT_REQUEST_TIMEOUT          | Таймаут запроса, сек                                                                                                               | 10                      |\n| RDM_UPLOADER_CLIENT_ENABLE_REQUEST_EMULATION | Включить эмуляцию отправки запросов                                                                                                | True                    |\n| RDM_TRANSFER_TASK_MINUTE                     | Настройка запуска периодической задачи выгрузки данных. Минута                                                                     | \'0\'                     |\n| RDM_TRANSFER_TASK_HOUR                       | Настройка запуска периодической задачи выгрузки данных. Час                                                                        | \'*/4\'                   |\n| RDM_TRANSFER_TASK_DAY_OF_WEEK                | Настройка запуска периодической задачи выгрузки данных. День недели                                                                | \'*\'                     |\n| RDM_TRANSFER_TASK_TIMEDELTA                  | Дельта между предыдущим и следующим запуском периодической задачи в секундах                                                       | 3600                    |\n| RDM_UPLOAD_STATUS_TASK_MINUTE                | Настройка запуска периодической задачи статуса загрузки данных в витрину. Минута                                                   | \'*/30\'                  |\n| RDM_UPLOAD_STATUS_TASK_HOUR                  | Настройка запуска периодической задачи статуса загрузки данных в витрину. Час                                                      | \'*\'                     |\n| RDM_UPLOAD_STATUS_TASK_DAY_OF_WEEK           | Настройка запуска периодической задачи статуса загрузки данных в витрину. День недели                                              | \'*\'                     |\n\n\n## Сборка и распространение\n\n## Инструкция для разработчика\n\n## Настройка PyCharm для работы\n\n## Запуск в системе\n\n## Запуск в контейнере\n\n## Правила внесения изменений\n',
    'author': 'BARS Group',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
